@@ -13,6 +13,7 @@
 #include <QTest>
 
 #include <KConfigGroup>
+#include <KIconTheme>
 #include <KSharedConfig>
 
 extern KICONTHEMES_EXPORT void uintToHex(uint32_t colorData, QChar *buffer);
@@ -38,12 +39,12 @@ private Q_SLOTS:
     {
         QStandardPaths::setTestModeEnabled(true);
 
-        const QStringList genericIconsFiles = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("mime/generic-icons"));
-        QVERIFY(!genericIconsFiles.isEmpty()); // KIconLoader relies on fallbacks to generic icons (e.g. x-office-document), which comes from a shared-mime-info
-                                               // file. Make sure it's installed!
+        // ensure we don't use the breeze icon set from our lib for these tests but the fake we set up below
+        KIconTheme::forceThemeForTests(QStringLiteral("fakebreeze"));
 
+        // we use an own fakebreeze that fallbacks to fakeoxygen
         KConfigGroup cg(KSharedConfig::openConfig(), "Icons");
-        cg.writeEntry("Theme", "breeze");
+        cg.writeEntry("Theme", "fakebreeze");
         cg.sync();
 
         testDataDir = QDir(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation));
@@ -63,61 +64,63 @@ private Q_SLOTS:
         QVERIFY(QFile::copy(QStringLiteral(":/app-image.png"), appDataDir.filePath(QStringLiteral("pics/image1.png"))));
         QVERIFY(QFile::copy(QStringLiteral(":/app-image.png"), appDataDir.filePath(QStringLiteral("pics/image2.png"))));
 
-        // set up a minimal Oxygen icon theme, in case it is not installed
-        QVERIFY(testIconsDir.mkpath(QStringLiteral("oxygen/22x22/actions")));
-        QVERIFY(testIconsDir.mkpath(QStringLiteral("oxygen/22x22/animations")));
-        QVERIFY(testIconsDir.mkpath(QStringLiteral("oxygen/22x22/apps")));
-        QVERIFY(testIconsDir.mkpath(QStringLiteral("oxygen/22x22/mimetypes")));
-        QVERIFY(testIconsDir.mkpath(QStringLiteral("oxygen/32x32/apps")));
-        QVERIFY(QFile::copy(QStringLiteral(":/oxygen.theme"), testIconsDir.filePath(QStringLiteral("oxygen/index.theme"))));
-        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("oxygen/22x22/apps/kde.png"))));
-        QVERIFY(QFile::copy(QStringLiteral(":/anim-22x22.png"), testIconsDir.filePath(QStringLiteral("oxygen/22x22/animations/process-working.png"))));
-        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("oxygen/22x22/mimetypes/text-plain.png"))));
-        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("oxygen/22x22/mimetypes/application-octet-stream.png"))));
-        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("oxygen/22x22/mimetypes/image-x-generic.png"))));
-        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("oxygen/22x22/mimetypes/video-x-generic.png"))));
-        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("oxygen/22x22/mimetypes/x-office-document.png"))));
-        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("oxygen/22x22/mimetypes/audio-x-generic.png"))));
-        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("oxygen/22x22/mimetypes/unknown.png"))));
-        QVERIFY(QFile::copy(QStringLiteral(":/test-32x32.png"), testIconsDir.filePath(QStringLiteral("oxygen/32x32/apps/kde.png"))));
+        // setup fake oxygen as fallback
+        QVERIFY(testIconsDir.mkpath(QStringLiteral("fakeoxygen/22x22/actions")));
+        QVERIFY(testIconsDir.mkpath(QStringLiteral("fakeoxygen/22x22/animations")));
+        QVERIFY(testIconsDir.mkpath(QStringLiteral("fakeoxygen/22x22/apps")));
+        QVERIFY(testIconsDir.mkpath(QStringLiteral("fakeoxygen/22x22/mimetypes")));
+        QVERIFY(testIconsDir.mkpath(QStringLiteral("fakeoxygen/32x32/apps")));
+        QVERIFY(QFile::copy(QStringLiteral(":/oxygen.theme"), testIconsDir.filePath(QStringLiteral("fakeoxygen/index.theme"))));
+        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("fakeoxygen/22x22/apps/kde.png"))));
+        QVERIFY(QFile::copy(QStringLiteral(":/anim-22x22.png"), testIconsDir.filePath(QStringLiteral("fakeoxygen/22x22/animations/process-working.png"))));
+        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("fakeoxygen/22x22/mimetypes/text-plain.png"))));
+        QVERIFY(
+            QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("fakeoxygen/22x22/mimetypes/application-octet-stream.png"))));
+        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("fakeoxygen/22x22/mimetypes/image-x-generic.png"))));
+        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("fakeoxygen/22x22/mimetypes/video-x-generic.png"))));
+        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("fakeoxygen/22x22/mimetypes/x-office-document.png"))));
+        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("fakeoxygen/22x22/mimetypes/audio-x-generic.png"))));
+        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("fakeoxygen/22x22/mimetypes/unknown.png"))));
+        QVERIFY(QFile::copy(QStringLiteral(":/test-32x32.png"), testIconsDir.filePath(QStringLiteral("fakeoxygen/32x32/apps/kde.png"))));
 
-        // set up a minimal Breeze icon theme, fallback to oxygen
-        QVERIFY(testIconsDir.mkpath(QStringLiteral("breeze/22x22/actions")));
-        QVERIFY(testIconsDir.mkpath(QStringLiteral("breeze/22x22/animations")));
-        QVERIFY(testIconsDir.mkpath(QStringLiteral("breeze/22x22/apps")));
-        QVERIFY(testIconsDir.mkpath(QStringLiteral("breeze/22x22/mimetypes")));
-        QVERIFY(testIconsDir.mkpath(QStringLiteral("breeze/22x22/appsNoContext")));
-        QVERIFY(testIconsDir.mkpath(QStringLiteral("breeze/22x22/appsNoType")));
-        QVERIFY(testIconsDir.mkpath(QStringLiteral("breeze/22x22/appsNoContextOrType")));
+        // set up a minimal fake Breeze icon theme, fallback to oxygen
+        QVERIFY(testIconsDir.mkpath(QStringLiteral("fakebreeze/22x22/actions")));
+        QVERIFY(testIconsDir.mkpath(QStringLiteral("fakebreeze/22x22/animations")));
+        QVERIFY(testIconsDir.mkpath(QStringLiteral("fakebreeze/22x22/apps")));
+        QVERIFY(testIconsDir.mkpath(QStringLiteral("fakebreeze/22x22/mimetypes")));
+        QVERIFY(testIconsDir.mkpath(QStringLiteral("fakebreeze/22x22/appsNoContext")));
+        QVERIFY(testIconsDir.mkpath(QStringLiteral("fakebreeze/22x22/appsNoType")));
+        QVERIFY(testIconsDir.mkpath(QStringLiteral("fakebreeze/22x22/appsNoContextOrType")));
 
-        const QString breezeThemeFile = testIconsDir.filePath(QStringLiteral("breeze/index.theme"));
+        const QString breezeThemeFile = testIconsDir.filePath(QStringLiteral("fakebreeze/index.theme"));
         QVERIFY(QFile::copy(QStringLiteral(":/breeze.theme"), breezeThemeFile));
         // kde.png is missing, it should fallback to oxygen
-        // QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("breeze/22x22/apps/kde.png"))));
+        // QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("fakebreeze/22x22/apps/kde.png"))));
         QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"),
-                            testIconsDir.filePath(QStringLiteral("breeze/22x22/appsNoContext/iconindirectorywithoutcontext.png"))));
+                            testIconsDir.filePath(QStringLiteral("fakebreeze/22x22/appsNoContext/iconindirectorywithoutcontext.png"))));
+        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"),
+                            testIconsDir.filePath(QStringLiteral("fakebreeze/22x22/appsNoType/iconindirectorywithouttype.png"))));
+        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"),
+                            testIconsDir.filePath(QStringLiteral("fakebreeze/22x22/appsNoContextOrType/iconindirectorywithoutcontextortype.png"))));
+        QVERIFY(QFile::copy(QStringLiteral(":/anim-22x22.png"), testIconsDir.filePath(QStringLiteral("fakebreeze/22x22/animations/process-working.png"))));
+        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("fakebreeze/22x22/mimetypes/text-plain.png"))));
         QVERIFY(
-            QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("breeze/22x22/appsNoType/iconindirectorywithouttype.png"))));
-        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"),
-                            testIconsDir.filePath(QStringLiteral("breeze/22x22/appsNoContextOrType/iconindirectorywithoutcontextortype.png"))));
-        QVERIFY(QFile::copy(QStringLiteral(":/anim-22x22.png"), testIconsDir.filePath(QStringLiteral("breeze/22x22/animations/process-working.png"))));
-        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("breeze/22x22/mimetypes/text-plain.png"))));
-        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("breeze/22x22/mimetypes/application-octet-stream.png"))));
-        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("breeze/22x22/mimetypes/image-x-generic.png"))));
-        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("breeze/22x22/mimetypes/video-x-generic.png"))));
-        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("breeze/22x22/mimetypes/x-office-document.png"))));
-        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("breeze/22x22/mimetypes/audio-x-generic.png"))));
-        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("breeze/22x22/mimetypes/unknown.png"))));
-        QVERIFY(QFile::copy(QStringLiteral(":/coloredsvgicon.svg"), testIconsDir.filePath(QStringLiteral("breeze/22x22/apps/coloredsvgicon.svg"))));
+            QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("fakebreeze/22x22/mimetypes/application-octet-stream.png"))));
+        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("fakebreeze/22x22/mimetypes/image-x-generic.png"))));
+        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("fakebreeze/22x22/mimetypes/video-x-generic.png"))));
+        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("fakebreeze/22x22/mimetypes/x-office-document.png"))));
+        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("fakebreeze/22x22/mimetypes/audio-x-generic.png"))));
+        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("fakebreeze/22x22/mimetypes/unknown.png"))));
+        QVERIFY(QFile::copy(QStringLiteral(":/coloredsvgicon.svg"), testIconsDir.filePath(QStringLiteral("fakebreeze/22x22/apps/coloredsvgicon.svg"))));
 
         // prepare some icons for our actions test
         // when querying breeze for 'one-two', we expect
         // 'one' from breeze instead of oxygen's 'one-two'.
-        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("oxygen/22x22/actions/one-two.png"))));
-        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("breeze/22x22/actions/one.png"))));
+        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("fakeoxygen/22x22/actions/one-two.png"))));
+        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("fakebreeze/22x22/actions/one.png"))));
 
-        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("breeze/22x22/actions/one-symbolic.png"))));
-        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("breeze/22x22/actions/three.png"))));
+        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("fakebreeze/22x22/actions/one-symbolic.png"))));
+        QVERIFY(QFile::copy(QStringLiteral(":/test-22x22.png"), testIconsDir.filePath(QStringLiteral("fakebreeze/22x22/actions/three.png"))));
 
         QVERIFY(QFile::setPermissions(breezeThemeFile, QFileDevice::ReadOwner | QFileDevice::WriteOwner));
         KConfig configFile(breezeThemeFile);
@@ -126,7 +129,7 @@ private Q_SLOTS:
         QStringList dirs = iconThemeGroup.readEntry("Directories", QStringList());
         for (int i : testSizes) {
             const QString relDir = QStringLiteral("%1x%1/emblems").arg(i);
-            const QString dir = testIconsDir.filePath(QStringLiteral("breeze/") + relDir);
+            const QString dir = testIconsDir.filePath(QStringLiteral("fakebreeze/") + relDir);
             QVERIFY(QDir().mkpath(dir));
 
             QPixmap img(i, i);
@@ -171,7 +174,7 @@ private Q_SLOTS:
         // properly, the next request for that icon should return the new icon
         // instead of the unknown icon.
 
-        QString actionIconsSubdir = QStringLiteral("oxygen/22x22/actions");
+        QString actionIconsSubdir = QStringLiteral("fakeoxygen/22x22/actions");
         QVERIFY(testIconsDir.mkpath(actionIconsSubdir));
         QString actionIconsDir = testIconsDir.filePath(actionIconsSubdir);
 
@@ -355,7 +358,7 @@ private Q_SLOTS:
         // of 'one-two' from oxygen.
         QString path;
         KIconLoader::global()->loadIcon(QStringLiteral("one-two"), KIconLoader::Desktop, 24, KIconLoader::DefaultState, QStringList(), &path);
-        QVERIFY(path.contains("breeze/22x22/actions"));
+        QVERIFY(path.contains("fakebreeze/22x22/actions"));
     }
 
     void testPathStore()
@@ -536,12 +539,12 @@ private Q_SLOTS:
         // Try to find "one-two-symbolic", but should fall back to "one-symbolic" which exists
         QString path;
         KIconLoader::global()->loadIcon(QStringLiteral("one-two-symbolic"), KIconLoader::Desktop, 24, KIconLoader::DefaultState, QStringList(), &path);
-        QVERIFY(path.contains("breeze/22x22/actions"));
+        QVERIFY(path.contains("fakebreeze/22x22/actions"));
         QVERIFY(path.contains("-symbolic"));
 
         // Try to find the non-existent "three-four-symbolic" but only "three" exists. It should fall back to the non-symbolic
         KIconLoader::global()->loadIcon(QStringLiteral("three-four-symbolic"), KIconLoader::Desktop, 24, KIconLoader::DefaultState, QStringList(), &path);
-        QVERIFY(path.contains("breeze/22x22/actions"));
+        QVERIFY(path.contains("fakebreeze/22x22/actions"));
         QVERIFY(!path.contains("-symbolic"));
     }
 };
