@@ -13,6 +13,7 @@
 
 #include "debug.h"
 
+#include <KColorSchemeManager>
 #include <KConfigGroup>
 #include <KLocalizedString> // KLocalizedString::localizedFilePath. Need such functionality in, hmm, QLocale? QStandardPaths?
 #include <KSharedConfig>
@@ -25,6 +26,7 @@
 #include <QMap>
 #include <QResource>
 #include <QSet>
+#include <QTimer>
 
 #include <private/qguiapplication_p.h>
 #include <qpa/qplatformtheme.h>
@@ -34,11 +36,23 @@
 #include <array>
 #include <cmath>
 
+#include "config.h"
+
 Q_GLOBAL_STATIC(QString, _themeOverride)
 
-#ifdef Q_OS_ANDROID
+#if !USE_BreezeIcons
+
+// on Android icon theme loading works differently and is managed by code in Kirigami
+// so don't actually touch anything icon-related here
+static void initThemeHelper()
+{
+    // postpone until QGuiApplication applies initial palette
+    QTimer::singleShot(0, [] {
+        // follow the system color, construct the global manager for that
+        (void)KColorSchemeManager::instance();
+    });
+}
 
-// on Android we are marked as porting AID, don't mess with theming
 void KIconTheme::initTheme()
 {
 }
@@ -86,18 +100,30 @@ static void initThemeHelper()
     // get config, with fallback to kdeglobals
     const auto config = KSharedConfig::openConfig();
 
-    // TODO: add Qt API to really fully override the engine
-    // https://codereview.qt-project.org/c/qt/qtbase/+/559108
-
     // enforce the theme configured by the user, with kdeglobals fallback
     // if not set, use Breeze
-    QString themeToUse = KConfigGroup(config, "Icons").readEntry("Theme", QStringLiteral("breeze"));
+    const QString themeToUse = KConfigGroup(config, "Icons").readEntry("Theme", QStringLiteral("breeze"));
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 8, 0)
+    // set our theme, Qt internally will still not fully use our engine and lookup
     QIcon::setThemeName(themeToUse);
+#else
+    // use Qt API to really fully override the engine, if we set KIconEngine the Key in our plugin will
+    // enforce that our engine is used
+    // https://codereview.qt-project.org/c/qt/qtbase/+/563241
+    QIcon::setThemeName(QStringLiteral("KIconEngine"));
+#endif
+
     // Tell KIconTheme about the theme, in case KIconLoader is used directly
     *_themeOverride() = themeToUse;
     qCDebug(KICONTHEMES) << "KIconTheme::initTheme() enforces the icon theme:" << themeToUse;
+
+    // postpone until QGuiApplication applies initial palette
+    QTimer::singleShot(0, [] {
+        // follow the system color, construct the global manager for that
+        (void)KColorSchemeManager::instance();
+    });
 }
-Q_COREAPP_STARTUP_FUNCTION(initThemeHelper)
 
 void KIconTheme::initTheme()
 {
@@ -120,6 +146,8 @@ void KIconTheme::initTheme()
 
 #endif
 
+Q_COREAPP_STARTUP_FUNCTION(initThemeHelper)
+
 class KIconThemeDir;
 class KIconThemePrivate
 {
@@ -348,6 +376,11 @@ KIconTheme::KIconTheme(const QString &name, const QString &appName, const QStrin
     // local embedded icons have preference
     icnlibs << QStringLiteral(":/icons");
 
+#ifdef Q_OS_ANDROID
+    // Android icon theme installed by Kirigami
+    icnlibs << QStringLiteral("assets:/qml/org/kde/kirigami");
+#endif
+
     // global icons
     icnlibs += QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("icons"), QStandardPaths::LocateDirectory);
 
@@ -416,7 +449,7 @@ KIconTheme::KIconTheme(const QString &name, const QString &appName, const QStrin
         KConfigGroup cg(d->sharedConfig, dirName);
         for (const auto &themeDir : std::as_const(themeDirs)) {
             const QString currentDir(themeDir + dirName + QLatin1Char('/'));
-            if (!addedDirs.contains(currentDir) && QDir(currentDir).exists()) {
+            if (!addedDirs.contains(currentDir) && QFileInfo::exists(currentDir)) {
                 addedDirs.insert(currentDir);
                 KIconThemeDir *dir = new KIconThemeDir(themeDir, dirName, cg);
                 if (dir->isValid()) {
@@ -726,7 +759,7 @@ KIconThemeDir::KIconThemeDir(const QString &basedir, const QString &themedir, co
         return;
     }
 
-    QString tmp = config.readEntry(QStringLiteral("Context"));
+    QString tmp = config.readEntry("Context", QString());
     if (tmp == QLatin1String("Devices")) {
         mContext = KIconLoader::Device;
     } else if (tmp == QLatin1String("MimeTypes")) {
@@ -763,7 +796,7 @@ KIconThemeDir::KIconThemeDir(const QString &basedir, const QString &themedir, co
         qCDebug(KICONTHEMES) << "Invalid Context=" << tmp << "line for icon theme: " << constructFileName(QString());
         return;
     }
-    tmp = config.readEntry(QStringLiteral("Type"), QStringLiteral("Threshold"));
+    tmp = config.readEntry("Type", QStringLiteral("Threshold"));
     if (tmp == QLatin1String("Fixed")) {
         mType = KIconLoader::Fixed;
     } else if (tmp == QLatin1String("Scalable")) {
@@ -775,10 +808,10 @@ KIconThemeDir::KIconThemeDir(const QString &basedir, const QString &themedir, co
         return;
     }
     if (mType == KIconLoader::Scalable) {
-        mMinSize = config.readEntry(QStringLiteral("MinSize"), mSize);
-        mMaxSize = config.readEntry(QStringLiteral("MaxSize"), mSize);
+        mMinSize = config.readEntry("MinSize", mSize);
+        mMaxSize = config.readEntry("MaxSize", mSize);
     } else if (mType == KIconLoader::Threshold) {
-        mThreshold = config.readEntry(QStringLiteral("Threshold"), 2);
+        mThreshold = config.readEntry("Threshold", 2);
     }
     mbValid = true;
 }
